@@ -1,4 +1,4 @@
-# response.py
+# bumbo/response.py
 
 import json
 
@@ -11,7 +11,7 @@ class Response:
         self.html = None
         self.text = None
         self.content_type = None
-        self.body = b''
+        self.body = b""
         self.status_code = 200
 
     def __call__(self, environ, start_response):
